@@ -15,10 +15,10 @@ from svtplay_dl.fetcher.http import HTTP
 class Bigbrother(Service, OpenGraphThumbMixin):
     supported_domains = ["bigbrother.se"]
 
-    def get(self, options):
+    def get(self):
         data = self.get_urldata()
 
-        if self.exclude(options):
+        if self.exclude(self.options):
             yield ServiceError("Excluding video")
             return
 
@@ -61,15 +61,15 @@ class Bigbrother(Service, OpenGraphThumbMixin):
 
         for i in renditions:
             if i["defaultURL"].endswith("f4m"):
-                streams = hdsparse(copy.copy(options), self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}), i["defaultURL"])
+                streams = hdsparse(copy.copy(self.options), self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}), i["defaultURL"])
                 if streams:
                     for n in list(streams.keys()):
                         yield streams[n]
 
             if i["defaultURL"].endswith("m3u8"):
-                streams = hlsparse(options, self.http.request("get", i["defaultURL"]), i["defaultURL"])
+                streams = hlsparse(self.options, self.http.request("get", i["defaultURL"]), i["defaultURL"])
                 for n in list(streams.keys()):
                     yield streams[n]
 
             if i["defaultURL"].endswith("mp4"):
-                yield HTTP(copy.copy(options), i["defaultURL"], i["encodingRate"]/1024)
\ No newline at end of file
+                yield HTTP(copy.copy(self.options), i["defaultURL"], i["encodingRate"]/1024)
\ No newline at end of file
